# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tg_bw_helper', 'tg_bw_helper.tests']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['bw_helper = tg_bw_helper.__main__:run']}

setup_kwargs = {
    'name': 'tg-bw-helper',
    'version': '1.0.2',
    'description': 'Thorgate helper for ansible vault password',
    'long_description': '==============================\nAnsible Vault Bitwarden Helper\n==============================\n\n    CLI command that connects two awesome tools together - Ansible Vault & Bitwarden Password Manager\n\n.. image:: https://gitlab.com/thorgate-public/tg-bw-helper/badges/master/pipeline.svg\n   :height: 20px\n\n.. image:: https://gitlab.com/thorgate-public/tg-bw-helper/badges/master/coverage.svg\n   :height: 20px\n\n----\n\n.. image:: https://asciinema.org/a/d8zWlTHhrtXYi8KhAvresaHK8.svg\n   :target: https://asciinema.org/a/d8zWlTHhrtXYi8KhAvresaHK8\n   :align: center\n\n----\n\n.. contents:: Table of Contents\n   :depth: 2\n\n####\nWhy?\n####\n\nAt Thorgate, we deploy project using Ansible. Ansible comes with awesome encrypted storage, and every storage needs it\'s own password to access it contents.\n\nWe also using Bitwarden to store company-wide passwords and sensitive information. And if we already are storing passwords to Ansible Vault\'s in Bitwarden, we thought why not use Bitwarden CLI tool to pass these passwords directly to Ansible Vault?\n\nAnd that\'s how this project was born 😎\n\n###############\nGetting Started\n###############\n\n*************\nPrerequisites\n*************\n\nWe need these tools to be installed:\n\n* Python 3.8+ & Pip\n* `Ansible <https://docs.ansible.com/ansible/latest/installation_guide/intro_installation.html?extIdCarryOver=true&sc_cid=701f2000001OH7YAAW#installing-ansible>`_\n* Ansible project that uses `Ansible Vault <https://docs.ansible.com/ansible/latest/cli/ansible-vault.html>`_\n* `Bitwarden Account <https://bitwarden.com>`_\n* `Bitwarden CLI <https://bitwarden.com/help/article/cli/#download-and-install>`_\n\nWe strongly recommend installing Python packages in dedicated and isolated virtual environments. There are several tools that helps manage virtual environments:\n\n* `Virtualenv <https://docs.python.org/3/library/venv.html#module-venv>`_\n* `Pipenv <https://pipenv.pypa.io/en/latest/#install-pipenv-today>`_\n* `Poetry <https://python-poetry.org/docs/#installation>`_ (We will be using this one)\n\n************\nInstallation\n************\n\nWe assume several things:\n\n* That you have existing or starting new Ansible project\n* That your Ansible installation lives in virtual environment\n\nBased on these assumptions, for installation you need to add this package into your virtual environment. For example you might run ``$ poetry add tg-bw-helper``\n\n***********************\nSetting Up With Ansible\n***********************\n\n1. Create if not yet existing shell script with this example content (it can be named ``ask-vault-pass.sh``) - note that you do not need to add ``poetry run`` before invoking ``bw_helper`` here, or activate virtualenv etc., since your ansible will be already running in correct environment\n\n   .. code-block:: bash\n\n      #!/bin/sh\n      bw_helper --vault-item "Ansible Vault" --vault-item-field "Password"\n\n2. Make sure that this script is executable! If not, run ``$ sudo chmod +x ask-vault-pass.sh``\n3. Edit ``ansible.cfg`` to specify script that Ansible will be using to get Vault password\n\n   .. code-block:: ini\n\n      [defaults]\n      vault_password_file=./ask-vault-pass.sh\n\n#####\nUsage\n#####\n\nNow when all these steps completed:\n\n* ``tg-bw-helper`` is installed into virtual environment where Ansible is installed\n* Ansible project is configured to use special script\n\nWe are ready to use the tool:\n\n1. Run ``$ bw login`` (Needs to be run once per user session)\n2. Run your usual Ansible playbook that previously asked for Vault password\n3. Enter Bitwarden master password\n\n###########\nCLI Options\n###########\n\n--bw-executable      Optional, should point to bw executable, defaults to /usr/bin/bw, can also be set with ``TG_BW_AP_EXECUTABLE_PATH`` env variable\n--fallback-prompt    optional, prompt to display if bw fails, defaults to "Vault password: ", can also be set with ``TG_BW_AP_FALLBACK_PROMPT`` env variable\n--vault-item      vault item ID or name, should be specific since tool will fail if multiple items are found\n\n      * **Item name** is what you see as it\'s name in bitwarden UI\n      * **Item ID** is useful if you have two items with same name, you can learn it by using bitwarden CLI (use ``bw login`` to login, follow the instructions for how to pass the session information over to the next command, and then use ``bw list items --search <item name>``. You will get json array of matching objects, each object will have ID that you can use.)\n--vault-item-field      optional, field to use on the item. If not specified, password is used. Examples:\n\n      * You have an item "Awesome project ansible vault" with password "123", and you want to use "123". You do not specify ``--valut-item-field`` in this case.\n      * You have an item "Ansible secrets" with password set to "abc", that has additional fields "Test server ansible" set to "123" and "Live server ansible" set to "456", and you want to use "123". You specify ``--valut-item-field="Test server ansible"`` in this case.\n\n############\nContributing\n############\n\nContributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are greatly appreciated.\n\n**********\nDeveloping\n**********\n\nFor local development project repository contains ``pyproject.toml`` and ``poetry.lock``. When using them with `Poetry <https://python-poetry.org/docs/#installation>`_ you will be able to recreate ready to use environment.\n\nWe also added ``Makefile`` that contains lots of useful commands to help setup the project, run tests and lint code. Do check it out by running ``make``\n\n**********\nOpening MR\n**********\n\n1. Clone the Project\n2. Create your Feature Branch (``git checkout -b feature/AmazingFeature``)\n3. Commit your Changes (``git commit -m \'Add some AmazingFeature\'``)\n4. Push to the Branch (``git push origin feature/AmazingFeature``)\n5. Open a Merge Request\n\n#######\nLicense\n#######\n\nDistributed under the MIT License. See LICENSE for more information.\n',
    'author': 'Sergey Kovalskiy',
    'author_email': 'sergey@thorgate.eu',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://thorgate.eu',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
